==> deepin-repair-tools_1.0.9.orig.tar.xz: deepin-repair-tools-1.0.9/translations/deepin-repair-tools_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>DPKGRepair</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkg_repair_plugin.h" line="21"/>
        <source>DPKG Repair</source>
        <translation>Reparar DPKG</translation>
    </message>
</context>
<context>
    <name>DPKGRepairWidget</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="33"/>
        <source>Show details</source>
        <translation>Exibir detalhes</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="34"/>
        <source>Hide details</source>
        <translation>Ocultar detalhes</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="39"/>
        <source>Repair</source>
        <translation>Reparar</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="40"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="83"/>
        <source>Cannot install or upgrade application</source>
        <translation>Não foi possível instalar ou atualizar a aplicação</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="104"/>
        <source>Repairing, please wait...</source>
        <translation>Reparando, por favor aguarde...</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="131"/>
        <source>Repair failed</source>
        <translation>Falha ao reparar</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="134"/>
        <source>Repair succeeded</source>
        <translation>Reparado com sucesso</translation>
    </message>
</context>
<context>
    <name>DiskClean</name>
    <message>
        <location filename="../plugins/disk_clean/disk_clean_plugin.h" line="22"/>
        <source>Disk Clean</source>
        <translation>Limpeza de disco</translation>
    </message>
</context>
<context>
    <name>DiskCleanWidget</name>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="62"/>
        <source>System partition</source>
        <translation>Partição do sistema</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="64"/>
        <source>Clean</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="67"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="152"/>
        <source>%1 (on %2)</source>
        <translation>%1 (de %2)</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="191"/>
        <source>Cleaning %1</source>
        <translation>Limpeza %1</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="237"/>
        <source>%1 has been cleaned up</source>
        <translation>%1 foi limpo</translation>
    </message>
</context>
<context>
    <name>GrubRepair</name>
    <message>
        <location filename="../plugins/grub_repair/grub_repair_plugin.h" line="21"/>
        <source>Boot Repair</source>
        <translation>Reparo da inicialização</translation>
    </message>
</context>
<context>
    <name>GrubRepairWidget</name>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="31"/>
        <source>Show details</source>
        <translation>Exibir detalhes</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="32"/>
        <source>Hide details</source>
        <translation>Ocultar detalhes</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="36"/>
        <source>Repair</source>
        <translation>Reparar</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="37"/>
        <source>Cannot find boot menu to enter system</source>
        <translation>Não foi possível encontrar o menu de boot para entrar no sistema</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="41"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="93"/>
        <source>Repairing, please wait...</source>
        <translation>Reparando, por favor aguarde...</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="147"/>
        <source>Repair succeeded</source>
        <translation>Reparado com sucesso</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="150"/>
        <source>Repair failed</source>
        <translation>Falha ao reparar</translation>
    </message>
</context>
<context>
    <name>PasswordReset</name>
    <message>
        <location filename="../plugins/password_reset/password_reset_plugin.h" line="21"/>
        <source>Password Reset</source>
        <translation>Senha Redefinida</translation>
    </message>
</context>
<context>
    <name>PasswordResetWidget</name>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="29"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="28"/>
        <source>Reset password</source>
        <translation>Redefinir senha</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="30"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="31"/>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="32"/>
        <source>Confirm password</source>
        <translation>Confirma senha</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="81"/>
        <source>Please enter a new password</source>
        <translation>Por favor, digite uma nova senha</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="97"/>
        <source>The two passwords don&apos;t match</source>
        <translation>As duas senhas não correspondem</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="128"/>
        <source>Reset password successfully</source>
        <translation>Senha redefinida com sucesso</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="154"/>
        <source>Forgot login password</source>
        <translation>Esqueceu a senha</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="142"/>
        <source>%1 (on %2)</source>
        <translation>%1 (de %2)</translation>
    </message>
</context>
<context>
    <name>PermissionsRepair</name>
    <message>
        <location filename="../plugins/permissions_repair/permissions_repair_plugin.h" line="21"/>
        <source>Privilege Repair</source>
        <translation>Reparo de privilégios</translation>
    </message>
</context>
<context>
    <name>PermissionsRepairWidget</name>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="23"/>
        <source>Cannot enter desktop due to privilege error</source>
        <translation>Não é possível entrar na área de trabalho devido a erro de privilégio</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="26"/>
        <source>Repair</source>
        <translation>Reparar</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="27"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="72"/>
        <source>Repairing, please wait...</source>
        <translation>Reparando, por favor aguarde</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="91"/>
        <source>Reset privilege successfully</source>
        <translation>Privilégio redefinido com sucesso</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="94"/>
        <source>Reset privilege failed</source>
        <translation>A redefinição de privilégios falhou</translation>
    </message>
</context>
<context>
    <name>ScanningPage</name>
    <message>
        <location filename="../src/scanningpage.cpp" line="27"/>
        <source>Checking hard disk status, please wait...</source>
        <translation>Verificando o estado do disco rígido, por favor aguarde...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="36"/>
        <source>Repair</source>
        <translation>Reparar</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="40"/>
        <source>Restart Now</source>
        <translation>Reiniciar agora</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="139"/>
        <source>Hard disk partition %1 error, please repair</source>
        <translation>Erro na partição %1 do disco rígido, por favor repare</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="151"/>
        <source>Please restart your computer to finish repairing</source>
        <translation>Por favor reinicie o seu computador para concluir a reparação</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="177"/>
        <source>Repairing hard disk, please wait...</source>
        <translation>Reparando o disco rígido, por favor aguarde...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="140"/>
        <source>The repair may cause data loss, please confirm and continue</source>
        <translation>O reparo pode causar perda de dados, por favor confirme e continue</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="38"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="150"/>
        <source>Repair succeeded</source>
        <translation>Reparado com sucesso</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="156"/>
        <source>Repair failed</source>
        <translation>Falha ao reparar</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Repair</source>
        <translation>Deepin Reparo</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="46"/>
        <source>Deepin Repair is a tool to help users quickly fix some issues in deepin, including hard disk detecting, disk cleaning, DPKG repairing, boot repairing, privilege repairing, password reset, etc.</source>
        <translation>Deepin Repair é uma ferramente para ajudar os usuários a concertarem alguns problemas rapidamente, incluindo detector de disco rígido, limpeza de disco, reparação do DPKG, reparação de boot, recuperação de privilégios, reset de senha, etc.</translation>
    </message>
</context>
</TS>

==> deepin-repair-tools_1.0.14.orig.tar.xz: deepin-repair-tools-1.0.14/translations/deepin-repair-tools_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>DPKGRepair</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkg_repair_plugin.h" line="21"/>
        <source>DPKG Repair</source>
        <translation>Reparar DPKG</translation>
    </message>
</context>
<context>
    <name>DPKGRepairWidget</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="33"/>
        <source>Show details</source>
        <translation>Exibir detalhes</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="34"/>
        <source>Hide details</source>
        <translation>Ocultar detalhes</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="39"/>
        <source>Repair</source>
        <translation>Reparar</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="40"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="83"/>
        <source>Cannot install or upgrade application</source>
        <translation>Não foi possível instalar ou atualizar o aplicativo</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="104"/>
        <source>Repairing, please wait...</source>
        <translation>Reparando, por favor aguarde...</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="131"/>
        <source>Repair failed</source>
        <translation>Falha ao reparar</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="134"/>
        <source>Repair successful</source>
        <translation>Reparo finalizado</translation>
    </message>
</context>
<context>
    <name>DiskClean</name>
    <message>
        <location filename="../plugins/disk_clean/disk_clean_plugin.h" line="22"/>
        <source>Disk Clean</source>
        <translation>Limpeza do disco</translation>
    </message>
</context>
<context>
    <name>DiskCleanWidget</name>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="62"/>
        <source>System partition</source>
        <translation>Partição do sistema</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="64"/>
        <source>Clean</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="67"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="153"/>
        <source>%1 (on %2)</source>
        <translation>%1 (de %2)</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="192"/>
        <source>Cleaning %1</source>
        <translation>Limpando %1</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="238"/>
        <source>%1 has been cleaned up</source>
        <translation>%1 foi limpo</translation>
    </message>
</context>
<context>
    <name>GrubRepair</name>
    <message>
        <location filename="../plugins/grub_repair/grub_repair_plugin.h" line="21"/>
        <source>Boot Repair</source>
        <translation>Reparo da inicialização</translation>
    </message>
</context>
<context>
    <name>GrubRepairWidget</name>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="31"/>
        <source>Show details</source>
        <translation>Exibir detalhes</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="32"/>
        <source>Hide details</source>
        <translation>Ocultar detalhes</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="36"/>
        <source>Repair</source>
        <translation>Reparar</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="37"/>
        <source>Cannot find boot menu to enter system</source>
        <translation>Não foi possível encontrar o menu de boot para entrar no sistema</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="41"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="93"/>
        <source>Repairing, please wait...</source>
        <translation>Reparando, por favor aguarde...</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="147"/>
        <source>Repair successful</source>
        <translation>Reparo finalizado</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="150"/>
        <source>Repair failed</source>
        <translation>Falha ao reparar</translation>
    </message>
</context>
<context>
    <name>PasswordReset</name>
    <message>
        <location filename="../plugins/password_reset/password_reset_plugin.h" line="21"/>
        <source>Password Reset</source>
        <translation>Senha Redefinida</translation>
    </message>
</context>
<context>
    <name>PasswordResetWidget</name>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="29"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="28"/>
        <source>Reset password</source>
        <translation>Redefinir senha</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="30"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="31"/>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="32"/>
        <source>Confirm password</source>
        <translation>Confirma senha</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="81"/>
        <source>Please enter a new password</source>
        <translation>Por favor, digite uma nova senha</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="97"/>
        <source>Passwords do not match</source>
        <translation>Senhas não conferem</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="130"/>
        <source>Reset password successfully</source>
        <translation>Senha redefinida com sucesso</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="156"/>
        <source>Forgot login password</source>
        <translation>Esqueceu a senha</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="144"/>
        <source>%1 (on %2)</source>
        <translation>%1 (de %2)</translation>
    </message>
</context>
<context>
    <name>PermissionsRepair</name>
    <message>
        <location filename="../plugins/permissions_repair/permissions_repair_plugin.h" line="21"/>
        <source>Privilege Repair</source>
        <translation>Reparo de privilégios</translation>
    </message>
</context>
<context>
    <name>PermissionsRepairWidget</name>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="23"/>
        <source>Cannot enter desktop due to privilege error</source>
        <translation>Não é possível entrar na área de trabalho devido a erro de privilégio</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="26"/>
        <source>Repair</source>
        <translation>Reparar</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="27"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="71"/>
        <source>Repairing, please wait...</source>
        <translation>Reparando, por favor aguarde</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="90"/>
        <source>Reset privilege successfully</source>
        <translation>Privilégio redefinido com sucesso</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="93"/>
        <source>Reset failed</source>
        <translation>Redefinição falhou</translation>
    </message>
</context>
<context>
    <name>ScanningPage</name>
    <message>
        <location filename="../src/scanningpage.cpp" line="27"/>
        <source>Checking hard disk status, please wait...</source>
        <translation>Verificando o estado do disco rígido, por favor aguarde...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="37"/>
        <source>Repair</source>
        <translation>Reparar</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="41"/>
        <source>Restart Now</source>
        <translation>Reiniciar agora</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="149"/>
        <source>Hard disk partition %1 error, please repair</source>
        <translation>Erro na partição %1 do disco rígido, por favor repare</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="160"/>
        <source>Repair successful</source>
        <translation>Reparo finalizado</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="161"/>
        <source>Please restart your computer to finish repairing</source>
        <translation>Por favor reinicie o seu computador para concluir a reparação</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="187"/>
        <source>Repairing hard disk, please wait...</source>
        <translation>Reparando o disco rígido, por favor aguarde...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="150"/>
        <source>The repair may cause data loss, please confirm and continue</source>
        <translation>O reparo pode causar perda de dados, por favor confirme e continue</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="39"/>
        <source>Done</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="166"/>
        <source>Repair failed</source>
        <translation>Falha ao reparar</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="47"/>
        <source>Deepin Repair</source>
        <translation>Reparador</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="48"/>
        <source>Deepin Repair is a tool to help users quickly fix some issues in deepin, including hard disk detecting, disk cleaning, DPKG repairing, boot repairing, privilege repairing, password reset, etc.</source>
        <translation>Reparador é uma ferramente para ajudar os usuários a concertarem alguns problemas rapidamente, incluindo detector de disco rígido, limpeza de disco, reparação do DPKG, reparação de boot, recuperação de privilégios, redefinição de senha, etc.</translation>
    </message>
</context>
</TS>
